==> oglio-2.3.1.tar.gz: oglio-2.3.1/README.md <==
![](https://github.com/hasii2011/code-ally-basic/blob/master/developer/agpl-license-web-badge-version-2-256x48.png "AGPL")

[![Maintenance](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://GitHub.com/Naereen/StrapDown.js/graphs/commit-activity)
[![CircleCI](https://dl.circleci.com/status-badge/img/gh/hasii2011/oglio/tree/master.svg?style=shield)](https://dl.circleci.com/status-badge/redirect/gh/hasii2011/oglio/tree/master)
[![PyPI version](https://badge.fury.io/py/oglio.svg)](https://badge.fury.io/py/oglio)

# Introduction
Provides a common way to parse and write Pyut XML files.  Additionally, removes this code from 
Pyut and places in a new project, so we can easily version the library.  Furthermore, it allows
the development of an IOXml plugin for Pyut with common code

# Overview

___

## Developer Notes
This project uses [buildlackey](https://github.com/hasii2011/buildlackey) for day-to-day development builds

___

## Note
For all kinds of problems, requests, enhancements, bug reports, etc.,
please drop me an e-mail.
Written by <a href="mailto:email@humberto.a.sanchez.ii@gmail.com?subject=Hello Humberto"> Humberto A. Sanchez II</a> (C) 2024


---
I am concerned with the direction GitHub's Copilot project.

![](https://github.com/hasii2011/code-ally-basic/blob/master/developer/SillyGitHub.png)

I urge you to read about the
[Give up GitHub](https://GiveUpGitHub.org) campaign from
[the Software Freedom Conservancy](https://sfconservancy.org).

While I do not advocate for all the issues listed there, I do not like that
a company like Microsoft may profit from open source projects.

I continue to use GitHub because it offers the services I need for free.
But I continue to monitor their terms of service.

I do not consent to any use of this project's code by the GitHub Copilot project it is done without my permission.

==> oglio-2.4.0.tar.gz: oglio-2.4.0/README.md <==
![](https://github.com/hasii2011/code-ally-basic/blob/master/developer/agpl-license-web-badge-version-2-256x48.png "AGPL")

[![Maintenance](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://GitHub.com/Naereen/StrapDown.js/graphs/commit-activity)
[![CircleCI](https://dl.circleci.com/status-badge/img/gh/hasii2011/oglio/tree/master.svg?style=shield)](https://dl.circleci.com/status-badge/redirect/gh/hasii2011/oglio/tree/master)
[![PyPI version](https://badge.fury.io/py/oglio.svg)](https://badge.fury.io/py/oglio)

# Introduction

This package provides a common way to read and write [Pyut](https://github.com/hasii2011/pyut) XML files.  Additionally, it removes this code from 
Pyut and places in a new package, so we can easily version the library.  Furthermore, it allows
the development of an IOXml plugin for Pyut with common code.

# Overview

___

## Developer Notes
This project uses [buildlackey](https://github.com/hasii2011/buildlackey) for day-to-day development builds

___

## Note
For all kinds of problems, requests, enhancements, bug reports, etc.,
please drop me an e-mail.
Written by <a href="mailto:email@humberto.a.sanchez.ii@gmail.com?subject=Hello Humberto"> Humberto A. Sanchez II</a> (C) 2025


---
I am concerned with the direction GitHub's Copilot project.

![](https://github.com/hasii2011/code-ally-basic/blob/master/developer/SillyGitHub.png)

I urge you to read about the
[Give up GitHub](https://GiveUpGitHub.org) campaign from
[the Software Freedom Conservancy](https://sfconservancy.org).

While I do not advocate for all the issues listed there, I do not like that
a company like Microsoft may profit from open source projects.

I continue to use GitHub because it offers the services I need for free.
But I continue to monitor their terms of service.

I do not consent to any use of this project's code by the GitHub Copilot project it is done without my permission.
